
global work "$path/working_data"
global figure "$path/figures"
global table "$path/tables"

**===========================================================================**
** County-Level Pretrends 
**===========================================================================**

	use "$work/CFPS_countyvar.dta", clear 
	cd "$figure"

	keep if year<2013 & year>2004 
	ren countyid_CFPS countyid 
	gen Population_cal=GDP*1000/GDPpc
	gen logGDP=log(GDP)
	gen logGvtExp=log(GvtExp)
	gen logGvtInc=log(GvtInc)
	gen logGDPpc=log(GDPpc)
	gen logPop=log(Population)
	gen logRurEmp=log(RurEmp) 
	gen logEmp=log(Employee)
	gen logRurInc=log(RurInc)
	gen logPrmStd=log(PrmStd)
	gen logMdStd=log(MdStd)

	replace PrmStd=. if year<2007
	replace MdStd=. if year<2007

	foreach x in GDP PrmStd MdStd logGDPpc logGvtInc logGvtExp logRurInc RurInc GDPpc_cal Population logPop{
		gen `x'_mis=(mi(`x'))
		bys countyid: egen `x'_misN=total(`x'_mis)
		drop  `x'_mis
	}

	replace GDP=. if GDP_misN>0
	replace PrmStd=. if PrmStd_misN>2
	replace MdStd=. if MdStd_misN>2
	replace logGvtInc=. if logGvtInc_misN>0
	replace logGvtExp=. if logGvtExp_misN>0
	replace GDPpc_cal=.  if GDPpc_cal_misN>0 
	replace logRurInc=. if logRurInc_misN>0
	replace RurInc=. if RurInc_misN>0
	replace Population=. if Population_misN>0
	replace logPop=. if logPop_misN>0
	gen PrmStd_pt=PrmStd/Population
	gen MdStd_pt=MdStd/Population
	gen PrmMdStd_pt=PrmStd_pt+MdStd_pt
	gen  PrmMdStd=PrmStd +MdStd
	replace logGDPpc=. if logGDPpc_misN>0
	gen logPrmMdStd=log(PrmMdStd) 
	replace PrmMdStd=PrmMdStd/10 
 	
	////////////////////////
	global t treat2
	////////////////////////
	replace PrmMdStd=PrmMdStd*10 
	replace GDPpc=GDPpc/1000 
	replace RurInc=RurInc/1000
	replace GDP=GDP/1000 
	replace GvtExp=GvtExp/1000
	replace GvtInc=GvtInc/1000 
	replace RetailSales=RetailSales/1000 
	replace Rural_POP=Rural_POP/1000 
	replace Population=Population/1000
	
	capture label variable countyid_CFPS "county CFPS ID"
	capture label variable countyid_NBS "county NBS ID"
	capture label variable provcd "province NBS ID"
	capture label variable Employee "Number of Employees (k.pers)"
	capture label variable GDP "GDP (bl.RMB)"
	capture label variable logGDP "log GDP (m.RMB)"
	capture label variable logEmp "log Number of Employees (k.pers)"
	capture label variable GDPpc "GDP per capita (k.RMB)"
	capture label variable logGDPpc "log GDP per capita (RMB)"
	capture label variable GvtExp "Government Expenditure (bl.RMB)"
	capture label variable GvtInc "Government Income (bl.RMB)"
	capture label variable logGvtExp "log Government Expenditure (m.RMB)"
	capture label variable logGvtInc "log Government Income (m.RMB)"
	capture label variable logPrmStd "log Number of Primary School Stds (k.pers)"
	capture label variable RurInc "Rural Income per capita (k.RMB)"
	capture label variable logRurInc "log Rural Income per capita (RMB)"
	capture label variable logRurPop "log Rural Population (k.pers)"
	capture label variable PrmMdStd "Students in School (k.pers)"
	capture label variable logPrmMdStd "log Students in School (k.pers)"
 	lab var RetailSales "Retail Sales of Consumer Goods (bl.RMB)"
	lab var Rural_POP "Rural Population (ml.pers)"
	lab var Population "Population (ml.pers)"
	replace logPrmMdStd=1 if year<2007
	replace PrmMdStd=0 if year<2007
	replace FstScd_ratio=0 if year==2012 
	replace RetailSales=0 if year>2010 
	
	** Graph with CI 
	global varlist GDP Population GvtExp GvtInc Rural_POP RurInc  
	foreach y in $varlist {
	local lb : variable label `y' 
	forvalues i=2005/2012{
	eststo y`i': reg `y' $t if year==`i', vce(hc3)
	}
	
	coefplot y2005 || y2006 || y2007 || y2008 || y2009 || y2010 || y2011 || y2012 ///
	, bycoefs keep($t) level(95) ciopts(recast(rcap) lcolor(black) lw(.2)) lcolor(black) mcolor(black) msize(vsmall) vertical title("`lb'", size(small) margin(b=1)) xlab(1 "2005" 2 "06" 3 "07" 4 "08" 5 "09" 6 "10" 7 "11" 8 "2012", labsize(small) ) xline(5.5, lw(.2)) name(`y', replace) ylab(#4, labsize(vsmall) notick) graphreg(margin(medsmall)) xsca( lw(.1)) ysca( lw(.1))
	}
	
	local y PrmMdStd
	local lb : variable label `y' 
	forvalues i=2007/2012{
	eststo y`i': reg `y' $t if year==`i', vce(hc3)
	}
	
	coefplot y2007 || y2008 || y2009 || y2010 || y2011 || y2012 ///
	, bycoefs keep($t) level(95) ciopts(recast(rcap) lcolor(black) lw(.2)) lcolor(black) mcolor(black) msize(vsmall) vertical title("`lb'", size(small) margin(b=1)) xlab(-1 "2005" 0 "06" 1 "07" 2 "08" 3 "09" 4 "10" 5 "11" 6 "2012", labsize(small) ) xline(3.5, lw(.2)) name(`y', replace) ylab(#4, labsize(vsmall) notick) graphreg(margin(medsmall)) xsca(r(-1.5 6.5) lw(.1)) ysca( lw(.1))
	
	local y RetailSales
	local lb : variable label `y' 
	forvalues i=2007/2012{
	eststo y`i': reg `y' $t if year==`i', vce(hc3)
	}
	
	coefplot y2005 || y2006 || y2007 || y2008 || y2009 || y2010 ///
	, bycoefs keep($t) level(95) ciopts(recast(rcap) lcolor(black) lw(.2)) lcolor(black) mcolor(black) msize(vsmall) vertical title("`lb'", size(small) margin(b=1)) xlab(1 "2005" 2 "06" 3 "07" 4 "08" 5 "09" 6 "10" 7 "11" 8 "2012", labsize(small) ) xline(5.5, lw(.2)) name(`y', replace) ylab(#4, labsize(vsmall) notick) graphreg(margin(medsmall)) xsca(r(.5 8.5) lw(.1)) ysca( lw(.1))
		
	graph combine $varlist PrmMdStd RetailSales, ysize(12) xsize(10) col(2) graphregion(margin(tiny))
	graph export "$figure/pretrend_2.pdf", replace   
	

**===========================================================================**
** Summary Statistics Children 
**===========================================================================**


cd "$table"
use "$work/ch1012_em_lg_ready.dta", clear
 	
	** statistics for main analysis sample 
 	keep if age10>=3 & age10<=22  
	keep if GrandAliveN_10>0 
 	keep if !mi(trpt2)
	lab var age Age 
	lab var sibling "Number of Siblings"
	lab var edu_exp "Education Expenditure" 
	lab var at_sch "Attending School"
	lab var age_p "Parents' Average Age"
	lab var edy_p "Parents' Average Schooling Years"

	set matsize 11000
	local list1 female age sibling age_p  edy_p  at_sch edu_exp
	outreg2 using sum_child.tex, replace excel sum(detail) keep(`list1' ) label ///
		sortvar(`list1' )
 
**===========================================================================**	
 ** Graph: Change in Enrollment by Cohort 
**===========================================================================**

	use "$work/ch1012_em_lg_ready.dta", clear
	cd "$figure"
	drop age12 
	gen age12=age10+2 
 	gen atsch10=at_sch if year==2010 
	gen atsch12=at_sch if year==2012 
 	
	//drop if mi(treat2) 
	bys age10 treat2 year: egen REnrol_m=mean(at_sch)
	bys age10 treat2 year gender: egen REnrol_mg=mean(at_sch)
	gen mER12=REnrol_m if year==2012
	gen mER10=REnrol_m if year==2010
	gen mER12_g=REnrol_mg if year==2012
	gen mER10_g=REnrol_mg if year==2010
	bys age10 treat2: egen MER12=mean(mER12)
	bys age10 treat2: egen MER10=mean(mER10)
	bys age10 treat2 gender: egen MER12g=mean(mER12_g)
	bys age10 treat2 gender: egen MER10g=mean(mER10_g)

	gen dER=MER12-MER10
	gen dERg=MER12g-MER10g
 
	keep if age10>=3 & age10<=22 
 	
	** Both  
	twoway (scatter dER age10 if treat2==0, c(direct) m(C) xla(5(5)20, labs(small)) xli(3(1)22, lp(solid) lc(dimgray)) msize(medium) mc(navy) )  ///
		(scatter dER age10 if treat2==1, c(direct) lp(dash) m(T) mc(maroon) ) ,   yscale(titlegap(*10)) ///
	ytitle("Change in Enrollment Rate", size(med) margin(r=-2)) xtit("Age in 2010", size(med)) ylabel(-.4(.2).8, labsize(small) angle(0)) legend(order(1 "Control Group"  2 "Treatment Group") size(small) nobox ring(0) pos(1) col(1)) graphregion(color(white)) yline(0, lc(gray))
	graph export "$figure/denroll_treat2.pdf", replace  

	** Sons 	
	twoway (scatter dERg age10 if treat2==0 & gender==1,  c(direct)  m(C)   xla(5(5)20, labs(small)) xli(3(1)22, lp(solid) lc(dimgray)) msize(medium) mc(navy) yaxis(1))  ///
	(scatter dERg age10 if treat2==1 & gender==1, c(direct)   m(T) mc(maroon) yaxis(2)) , xscale(titlegap(*10))  ///
	ytitle("Change in Enrollment Rate", size(med) margin(r=5) axis(2)) xtit("Age in 2010", size(med)) ylabel(-.4(.2).8, labsize(small)  angle(0) axis(2)) legend(order(1 "Control Group"  2 "Treatment Group") size(medsmall) nobox ring(0) pos(1) col(1)) saving(male, replace) title("Sons", size(med) margin(b=3)) ysca(off axis(1)) ysca(range(-.4 .8) axis(1))  ysca(range(-.4 .8) axis(2))  yline(0, lc(gray))

	** Daughters 
	twoway (scatter dERg age10 if treat2==0 & gender==0,c(direct) m(C)  xla(5(5)20, labs(small)) xli(3(1)22, lp(solid) lc(dimgray)) msize(medium) mc(navy) )  ///
	(scatter dERg age10 if treat2==1 & gender==0, c(direct)  m(T) mc(maroon) ) , xscale(titlegap(*10)) yscale(titlegap(*10)) ///
	ytitle("Change in Enrollment Rate", size(med) margin(r=-6) ) xtit("Age in 2010", size(med)) ylabel(-.4(.2).8, labsize(small) angle(0))  legend(order(1 "Control Group"  2 "Treatment Group") size(medsmall) nobox ring(0) pos(1) col(1))  saving(female, replace) title("Daughters", size(med) margin(b=3)) ysca(range(-.4 .8)) yline(0, lc(gray))

	graph combine female.gph  male.gph 
	graph display, xsize(18) ysize(11)
	graph export "$figure/Gdenroll_treat2.pdf", replace  


**===========================================================================**
** Census Cohort Trends 
**===========================================================================**

	use "$work/CFPS_countyvar" , clear 
	duplicates drop countyid_NBS, force 
	keep countyid_NBS countyid_CFPS provcd county_CN county_EN Treat* treat*  
	ren countyid_NBS countyid 
	merge 1:m countyid using "$raw/census2010.dta" 
	drop if _m==2
	drop _m 	
	
	keep if rural_hukou==1
	keep if hukou_place==1
	gen eduyr=6 if edu_level==2 
	replace eduyr=9 if edu_level==3
	replace eduyr=12 if edu_level==4
	replace eduyr=15 if edu_level==5
	replace eduyr=16 if edu_level==6
	replace eduyr=0 if edu_level==1
	replace eduyr=19 if edu_level==7
	
	** Gap with Confidence intervals 
	gen female=1-male 
	bys countyid age: egen NMale=total(male)
	bys countyid age: egen NFemale=total(female)
	gen GenderRatio=NMale/NFemale
	
	gen eduyr_f=eduyr if female 
	gen eduyr_m=eduyr if male 
	bys countyid age: egen MEdu=mean(eduyr_m)
	bys countyid age: egen FEdu=mean(eduyr_f)
	gen GenderEduGap=MEdu-FEdu 
	
	duplicates drop countyid age, force 
	
	** Gender Ratio 
	forvalues i=0/25{
	eststo a`i': reg GenderRatio treat2 if age==`i', vce(hc3)
	}
	
	coefplot a0 || a1 || a2 || a3 || a4 || a5 || a6 || a7 || a8 || a9 || a10 || a11 || a12 || a13 || a14 || a15 || a16 || a17 || a18 || a19 || a20  ///
	, bycoefs keep(treat2) level(95) ciopts(recast(rcap) lcolor(black) lw(.2)) lcolor(black) mcolor(black) msize(vsmall) vertical title("`lb'", size(small) margin(b=1)) xlab(1 "0" 2 "1" 3 "2" 4 "3" 5 "4" 6 "5" 7 "6" 8 "7" 9 "8" 10 "9" 11 "10" 12 "11" 13 "12" 14 "13" 15 "14" 16 "15" 17 "16" 18 "17" 19 "18" 20 "19" 21 "20" , labsize(small)) name(GenderRatio, replace) ylab(#5, labsize(small) notick) graphreg(margin(medsmall)) xsca(lw(.1)) ysca(lw(.1)) ytitle("b(Treatment)", size(small))title("(a) Gender Ratio", size(medsmall)) xtitle("Age in 2010", size(small) margin(t=1))
	
	
	** Education Gap 
	forvalues i=18/38{
	local j=`i'-18
	eststo a`j': reg GenderEduGap treat2 if age==`i', vce(hc3)
	}
	
	coefplot a0 || a1 || a2 || a3 || a4 || a5 || a6 || a7 || a8 || a9 || a10 || a11 || a12 || a13 || a14 || a15 || a16 || a17 || a18 || a19 || a20 ///
	, bycoefs keep(treat2) level(95) ciopts(recast(rcap) lcolor(black) lw(.2)) lcolor(black) mcolor(black) msize(vsmall) vertical title("`lb'", size(small) margin(b=1)) xlab(1 "18" 2 "19" 3 "20" 4 "21" 5 "22" 6 "23" 7 "24" 8 "25" 9 "26" 10 "27" 11 "28" 12 "29" 13 "30" 14 "31" 15 "32" 16 "33" 17 "34" 18 "35" 19 "36" 20 "37" 21 "38"  , labsize(small)) name(GenderEduGap, replace) ylab(#4, labsize(small) notick) graphreg(margin(medsmall)) xsca(lw(.1)) ysca(lw(.1)) xtitle("Age in 2010", size(small) margin(t=1)) ytitle("b(Treatment)", size(small)) title("(b) Gender Education Gap", size(medsmall))
	graph combine GenderRatio GenderEduGap, col(1) ysize(14) xsize(12) graphregion(margin(tiny))
	graph export "$figure/Census_CohortTrend.pdf", replace 
	
