
global work "$path/working_data"
global figure "$path/figures"
global table "$path/tables"
grstyle init 
grstyle set plain 

use "$work/ch1012_em_lg_ready.dta", clear

	keep if age10>=3 & age10<=22 
	keep if GrandAliveN_10>0 
	global bsc_ct age  age_p  edy_p  
	global cctr  ln_POP ln_GvtExp ln_GvtInc ln_GDP

	local t 2
	global ctr trpt`t' 
	gen edu_exp_cap1=edu_exp
	gen edu_exp_cap10=edu_exp
	gen edu_exp_cap5=edu_exp
	sum edu_exp, det
	replace edu_exp_cap1=`r(p99)' if edu_exp>`r(p99)' & !mi(edu_exp)
	replace edu_exp_cap5=`r(p95)' if edu_exp>`r(p95)' & !mi(edu_exp)
	replace edu_exp_cap10=`r(p90)' if edu_exp>`r(p90)' & !mi(edu_exp)
	
	replace edu_exp=edu_exp/1000 
	replace edu_exp_cap1=edu_exp_cap1/1000 
	replace edu_exp_cap5=edu_exp_cap5/1000 
	

** Heterogeneity By Cohort : COEFPLOT 
	 
	gen cohort=.
	replace cohort=1 if age10<=6
	replace cohort=2 if age10>=6 &  age10<=15
	replace cohort=3 if age10>=15 & age10<=18
	replace cohort=4 if age10>=18 & age10<=22

	forvalues c=1/4{ 
		forvalues f=0/1{
		eststo a`f'_c`c': reghdfe  at_sch  $ctr  $bsc_ct  $cctr if fem==`f' & cohort==`c', abs(i.countyid i.pro_yr)  vce(cl countyid)  
		eststo e`f'_c`c': qui reghdfe  edu_exp_cap1  $ctr  $bsc_ct if fem==`f' & cohort==`c', abs(i.countyid i.pro_yr)  vce(cl countyid)  
	}
	}

	coefplot (a0_c1,msymbol(c)) (a1_c1,msymbol(d) pstyle(p2)) , bylabel("6-8") ///
		|| (a0_c2) (a1_c2, pstyle(p2)),  bylabel(" 9-15") ///
		|| a0_c3 a1_c3 , bylabel("16-18") ///
		|| a0_c4 a1_c4 , bylabel("19-24") ///
		||, bycoefs vertical keep($ctr) pstyle(p1) plotlabels("Son" "Daughter") legend(size(med) region(color(none) margin(b=2)) pos(12)) xsca(r(1 4.5)) ylab(-.4(.2).2, labs(small)  angle(0)) graphregion(color(white)) levels(95 90) yline(0, lp(solid) lc(gray)) msize(medsmall) ciopts(recast(. rcap)) ytitle("Enrollment", size(med)) xtitle("Age in 2010", size(med)) name(attend, replace) xsca(off) grid(between)
		
	coefplot (e0_c1,msymbol(c)) (e1_c1,msymbol(d) pstyle(p2))  , bylabel("Preschool (3-6)") ///
		|| e0_c2 e1_c2 , bylabel("Compulsory (6-15)") ///
		|| e0_c3 e1_c3 , bylabel("High School (15-18)") ///
		|| e0_c4 e1_c4 , bylabel("Tertiary (18-22)") ///
		||, bycoefs vertical pstyle(p1) keep($ctr) plotlabels("Son" "Daughter") legend(off) xsca(r(1 4.5)) ylab(-4(2)2, labs(small) angle(0)) graphregion(color(white)) levels(95 90) yline(0, lp(solid) lc(gray)) msize(medsmall) ciopts(recast(. rcap)) ytitle("Expenditures (k)", size(med)) xtitle("Age in 2010", size(med) margin(t=-1)) name(expend, replace)  xsca(titlegap(*10)) xlab(,labsize(med)) grid(between)
		
	graph combine attend expend,  col(1)
	graph display, xsize(14) ysize(11)
  	graph export "$figure/byCohort.pdf", replace 
	
	
** Heterogeneity By Sibling Structure  
	ren Mmale MMale 
	gen mmale10=MMale if year==2010
	bys pid: egen MMale10=mean(mmale10)
	gen single=(sibling==0)

	eststo clear 
	eststo fs : reghdfe at_sch  $ctr  $bsc_ct  $cctr  $pre09  $pre08  $pre07  $pre06  $pre05 if fem==1 & single==1, abs(i.countyid i.pro_yr)  vce(cl countyid)  
	eststo fns: reghdfe at_sch  $ctr  $bsc_ct  $cctr  $pre09  $pre08  $pre07  $pre06  $pre05 if fem==1 & single==0, abs(i.fid i.pro_yr)  vce(cl fid)  
	eststo ms : reghdfe at_sch  $ctr  $bsc_ct  $cctr  $pre09  $pre08  $pre07  $pre06  $pre05 if fem==0 & single==1, abs(i.countyid i.pro_yr)  vce(cl countyid)  
	eststo mns: reghdfe at_sch  $ctr  $bsc_ct  $cctr  $pre09  $pre08  $pre07  $pre06  $pre05 if fem==0 & single==0, abs(i.fid i.pro_yr)  vce(cl fid)  
	eststo fmx : reghdfe at_sch  $ctr  $bsc_ct  $cctr  $pre09  $pre08  $pre07  $pre06  $pre05 if fem==1 & MMale>0 & MMale<1, abs(i.fid i.pro_yr)  vce(cl fid)  
	eststo mmx : reghdfe at_sch  $ctr  $bsc_ct  $cctr  $pre09  $pre08  $pre07  $pre06  $pre05 if fem==0 & MMale>0 & MMale<1, abs(i.fid i.pro_yr)  vce(cl fid)  
	
	keep if age10>15 
	eststo fse :  reghdfe edu_exp_cap5  $ctr  $bsc_ct  $cctr  $pre09  $pre08  $pre07  $pre06  $pre05 if fem==1 & single==1, abs(i.countyid i.pro_yr)  vce(cl countyid)  
	eststo fnse:  reghdfe edu_exp_cap5  $ctr  $bsc_ct  $cctr  $pre09  $pre08  $pre07  $pre06  $pre05 if fem==1 & single==0, abs(i.fid i.pro_yr)  vce(cl fid)  
	eststo mse :  reghdfe edu_exp_cap5  $ctr  $bsc_ct  $cctr  $pre09  $pre08  $pre07  $pre06  $pre05 if fem==0 & single==1, abs(i.countyid i.pro_yr)  vce(cl countyid)  
	eststo mnse:  reghdfe edu_exp_cap5  $ctr  $bsc_ct  $cctr  $pre09  $pre08  $pre07  $pre06  $pre05 if fem==0 & single==0, abs(i.fid i.pro_yr)  vce(cl fid)  
	eststo fmxe : reghdfe edu_exp_cap5  $ctr  $bsc_ct  $cctr  $pre09  $pre08  $pre07  $pre06  $pre05 if fem==1 & MMale>0 & MMale<1, abs(i.fid i.pro_yr)  vce(cl fid)  
	eststo mmxe : reghdfe edu_exp_cap5  $ctr  $bsc_ct  $cctr  $pre09  $pre08  $pre07  $pre06  $pre05 if fem==0 & MMale>0 & MMale<1, abs(i.fid i.pro_yr)  vce(cl fid)  

	coefplot ///
		(fs,  msymbol(d) label("Only daughter") pstyle(p2)) ///
		(ms,  msymbol(c) label("Only son")) ///
		(fns, msymbol(d) label("Daughter with sibling") pstyle(p2)) ///
		(mns, msymbol(c) label("Son with sibling")) ///
		(fmx, msymbol(d) label("Daughter w/ brother") pstyle(p2)) ///
		(mmx, msymbol(c) label("Son with sister")) ///
		, keep(  $ctr ) pstyle(p1) levels(95 90) ysc(off) xline(0, lp(solid) lc(gray)) graphregion(color(white)) mlabel mlabposition(12) mlabgap(*2) mlabsize(m) horizontal title("Enrollment", size(medlarge) margin(b=3)) msize(medsmall) ciopts(recast(. rcap))  legend(r(6) pos(9) rowg(8.5) region(col(white)) size(small) symxsize(.1) nobox) name(attend, replace) xlab(-.2(.1).3, labsize(small) format(%3.1f)) format(%3.2f)  

	coefplot ///
		(fse,  msymbol(d) label("single daughter") pstyle(p2)) ///
		(mse,  msymbol(c) label("single son")) ///
		(fnse, msymbol(d) label("daughter w/ sibling") pstyle(p2)) ///
		(mnse, msymbol(c) label("son w/ sibling")) ///
		(fmxe, msymbol(d) label("daughter w/ brother") pstyle(p2)) ///
		(mmxe, msymbol(c) label("son w/ sister")) ///
		, keep(trpt2)  pstyle(p1) levels(95 90) ysc(off) xline(0, lp(solid) lc(gray)) graphregion(color(white))  mlabel mlabposition(12) mlabgap(*2)  mlabsize(medsmall) horizontal title("Expenditures (k)", size(medlarge) margin(b=3)) msize(medsmall) ciopts(recast(. rcap))legend(r(6) pos(9) rowg(8.5) region(col(white) ) size(small) nobox)  name(expend, replace) xlab(, labsize(small) format(%3.0f))  format(%3.2f)  

	graph close _all
	grc1leg attend expend, graphregion(color(white))  legendfrom(attend) pos(9)
	graph export "$figure/bySibling.pdf", replace  
