
global raw_data "$path/raw_data"
global working_data "$path/working_data"
global out_files "$path/out_files"

********************************************************************************
**		 Merge 2011 and 2013 children sample 
********************************************************************************

use "$working_data/children13.dta", clear 
gen HHID=substr(householdID, 1, 9)
tab residence, m 
bys HHID childID: gen rpt=_N
drop if mi(age) & rpt>1 
drop if mi(hukou) & rpt>1

duplicates drop HHID childID, force 
drop rpt 

local trsf ptc ctp gctp ptgc gc_hrs
local control_ch age hukou catg residence occupation atsch edulv_fn male chN nadchN marital tinc yinc work  
local control_pr rs_N age_m age_f edu_yr_m edu_yr_f hukou_m hukou_f NRPS_N 
local control_fm fwealth fasset_rs communityID 
foreach x in  `trsf'  `control_ch' `control_pr' `control_fm'  {
ren `x' `x'13
}
drop versionID rctp rptc rgctp rptgc age_det  

save "$working_data/children13_temp.dta", replace 

use "$working_data/children11.dta", clear 
ren householdID HHID 

local trsf ptc ctp gctp ptgc gc_hrs
local control_ch age hukou residence atsch occu edulv_fn male chN adchN yinc tinc work  
local control_pr rs_N age_m age_f edu_yr_m edu_yr_f hukou_m hukou_f bio_child adopt_child NRPS_N
local control_fm fwealth fasset_rs communityID 
foreach x in  `trsf' `control_ch' `control_pr' `control_fm' {
ren `x' `x'11
}

drop adchN N_addau N_adson visit contact N_son N_dau 
bysort HHID childID: gen rpt=_n
tab rpt 
drop rpt 

save "$working_data/children11_temp.dta", replace 

merge 1:1 HHID childID using "$working_data/children13_temp.dta" 
drop ID 
keep if _merge==3 
gen age_gp=age13-age11 
drop if age_gp<0 
drop if  age_gp> 4 & !mi(age_gp)
replace age11=round(age11)
replace age11=age13-2 if age11==.  & !mi(age13)
replace age13=age11+2 if age13==. & !mi(age11) & !mi(hukou13) & hukou11==hukou13 

drop if mi(age11) & mi(age13)
gen male_d=male13-male11 
tab male_d,m 
drop if male_d==1 | male_d==-1
replace male11=male13 if mi(male11) & residence11==residence13
replace male11=male13 if mi(male11) & hukou11==hukou13 
replace male11=male13 if mi(male11) & edulv_fn11== edulv_fn13 & !mi(male13)

//sibling structure 
gen age=age11 
replace male11=male13 if mi(male11) & !mi(male13)
replace male13=male11 if mi(male13) & !mi(male11)
drop if mi(male13)
drop if mi(age)

bys HHID: egen mage=mean(age)
bys HHID: egen mnage=min(age)
bys HHID: egen mxage=max(age)
drop if age<=5 & mage>=16 
drop if age<=5 & mxage>=20 
drop if age<mxage-20 & age<10

bys HHID: gen sibling=_N-1 
bys HHID: egen maleN=total(male11)
gen male_sibling=maleN-male11 
gen female_sibling=sibling-male_sibling 

sort HHID age 
bys HHID: gen childid=_n 
bys HHID: gen totalchild=_N 
gen elder_sibling=totalchild-childid 
gen younger_sibling=childid-1 
drop childid mxage mnage maleN totalchild mage age

tab alive,m 
drop if alive==0 
ren catg13 type 
drop age_gp male_d _merge alive fawealth
ren occu11 occupation11 
egen ID=concat(HHID childID)

local control_fm fwealth fasset_rs communityID  
replace residence11=1 if mi(residence11) & residence13==1  & !mi(HHmember)
replace residence11=residence13 if residence13>1 & !mi(residence13) & ctp11>0 
 
lab define hukou 1"Agri Hukou" 2"Non-Agri Hukou" 3"Unified Hukou" 4"No Hukou" 
lab values hukou11 hukou 
lab values hukou13 hukou 
replace hukou11=hukou13 if !mi(hukou13) & mi(hukou11)
replace hukou13=hukou11 if !mi(hukou11) & mi(hukou13)
foreach x in age_m11 age_f11 age_m13 age_f13{
replace `x'=round(`x')
}
foreach x in age_f age_m {
replace `x'11=`x'13-2 if `x'13!=. & mi(`x'11)
replace `x'13=`x'11+2 if mi(`x'13) & !mi(`x'11)
} 
egen eduyr_f=rowmean(edu_yr_f11 edu_yr_f13)
egen eduyr_m=rowmean(edu_yr_m11 edu_yr_m13)
drop edu_yr_f11 edu_yr_f13 edu_yr_m11 edu_yr_m13
replace occupation11=. if occupation11==.d | occupation11==.r 
replace occupation11=occupation13 if mi(occupation11) & !mi(occupation13)
replace occupation13=occupation11 if mi(occupation13) & !mi(occupation11)
replace edulv_fn13=edulv_fn11 if mi(edulv_fn13) & !mi(edulv_fn11) & age11>24 
replace edulv_fn11=edulv_fn13 if mi(edulv_fn11) & !mi(edulv_fn13) & age11>24 

replace fwealth11=fwealth13/1.2224961 if mi(fwealth11) & !mi(fwealth13)
replace fwealth13=fwealth11*1.2224961 if mi(fwealth13) & !mi(fwealth11)

replace fasset_rs11=fasset_rs13/1.9919363 if mi(fasset_rs11) & !mi(fasset_rs13)
replace fasset_rs13=fasset_rs11*1.9919363 if mi(fasset_rs13) & !mi(fasset_rs11)
replace hukou_f11=hukou_f13 if mi(hukou_f11) & !mi(hukou_f13)
replace hukou_f13=hukou_f11 if mi(hukou_f13) & !mi(hukou_f11)
replace hukou_m11=hukou_m13 if mi(hukou_m11) & !mi(hukou_m13)
replace hukou_m13=hukou_m11 if mi(hukou_m13) & !mi(hukou_m11)

local trsf ptc ctp gctp ptgc gc_hrs
local control_ch age hukou residence atsch occupation edulv_fn male chN adchN yinc tinc work 
local control_pr rs_N age_m age_f edu_yr_m edu_yr_f hukou_m hukou_f NRPS_N

reshape long `trsf' `control_ch' `control_pr' `control_fm' , i(ID) j(year)
ren tinc income_ct
ren yinc income_vl 
drop marital nadchN adchN childID householdID 
label variable fwealth "family wealth "
label variable fasset_rs "parents' assets"
label variable rs_N "parents number "
label variable age_m "age of mother"
label variable age_f "age of father"
label variable eduyr_m "education year of mother(2 wave average) "
label variable eduyr_f "education year of mother(2 wave average) "
label variable hukou_m "mother's hukou"
label variable hukou_f "father's hukou"
label variable ctp "transfer to parents"
label variable ptc "transfer from parents"
label variable gctp "transfer grandchildren to parents "
label variable ptgc "transfer parents to grandchildren"
label variable gc_hrs "childcare hours"
label variable age "Child age"
label variable residence "Child residence"
label variable hukou "Child hukou"
label variable atsch "Child still at school"
label variable chN "Child's number of kids"
label variable  income_ct "Child income category"
lab var income_vl "Child income level" 
label variable work "Child work "
label variable occupation "Child  occupation"
label variable edulv_fn "Child  finished education level "
label variable male "Child male"
lab var ID "constructed child ID "
ren edulv_fn education
save "$working_data/children_temp.dta", replace 

use "$working_data/children_temp.dta", clear 
merge m:1 communityID using "$raw_data/psu.dta" 
keep if _merge==3
drop _merge 		
order province city urban_nbs areatype, bef(fwealth)

format %30.0f residence
drop edu_yr_m edu_yr_f

* transfer measures 
 gen nctp=ctp-ptc 
gen dm_up=(ctp>0)
gen dm_down=(ptc>0)
gen dm_nup=(nctp>0)
gen ln_ctp=log(ctp+1)
gen ln_ptc=log(ptc+1)

egen tctp=rowtotal(ctp gctp)
egen tptc=rowtotal(ptc ptgc)
gen ntctp=tctp-tptc 
gen dm_tup=(tctp>0)
gen dm_tdown=(tptc>0)
gen dm_ntup=(ntctp>0)
gen ln_tctp=log(tctp+1)
gen ln_tptc=log(tptc+1)

gen ln_fw=log(fwealth+1)
replace ln_fw=0 if fwealth<0 
gen ln_rsw=log(fasset_rs+1)
replace ln_rsw=0 if fasset_rs<0 
lab var ln_fw "log(family wealth), truncated at 0"
lab var ln_rsw "log(parents' asset), truncated at 0"
drop urban 
encode province, gen(prov)
order prov, bef(city)
drop province 
ren prov province 
bysort ID: egen mage=mean(age)
drop if mage<20 | mage>60 
foreach x in hukou hukou_f hukou_m {
replace `x'=2 if `x'==3 
replace `x'=. if `x'==4 
}

egen age_p=rowmean(age_f age_m)
egen age_px=rowmax(age_f age_m)
bysort ID: egen mage_p=mean(age_p)
lab var mage "Child two wave mean age "
lab var age_p "mean age of parents"
lab var age_px "max age of parents"
lab var mage_p "Parents: two wave mean age"
drop if mage_p<30 | mage_p>90 

save "$working_data/children.dta", replace 
capture erase "$working_data/children11_temp.dta" 

** Prepare analysis dataset 
	use "$working_data/children.dta", clear 

	gen ctp_tem=ctp if year==11
	bysort ID: egen ctp11=mean(ctp_tem)
	drop ctp_tem  

	gen cores=(residence==0)
	tab cores year 
	gen cores_tem=cores if year==11 
	bysort ID: egen cores11=mean(cores_tem)
	drop cores_tem
	tab cores11,m 

	gen group=20 if mage<30 
	replace group=30 if mage>=30 & mage<40 
	replace group=40 if mage>=40 & mage<50 
	replace group=50 if mage>=50 
	tab group,m 
	egen mhukou=rowmean(hukou_f hukou_m)
	bysort HHID: egen Mhukou=mean(mhukou)
	keep if Mhukou==1 
	drop mhukou Mhukou hukou_m hukou_f
	drop if area=="210"

	gen ln_inc=log(income_vl+1)

	gen age_t=age if year==11 
	bysort ID: egen age11=mean(age_t)
	drop age_t
	gen edu_yr=0 if education==1
	replace edu_yr=3 if educa==2
	replace edu_yr=6 if educa==3
	replace edu_yr=9 if educa==4
	replace edu_yr=12 if educa==5
	replace edu_yr=16 if educa==6 

	gen age2=age^2 
	egen pro_yr=group(province year) 
	gen female=1-male 
	egen eduyr_p=rowmean(eduyr_f eduyr_m)   
	lab var age_p "Parents' Age"
	lab var eduyr_p "Parents' Schooling Year"
	lab var rs_N "Parents Both Alive"
	lab var ln_inc "log(Income)"
	lab var female "Female"
	lab var ln_rsw "log(Parents' Wealth)"
save "$working_data/children_em.dta", replace 

*** Merge with Parents' Information 
	use "$working_data/parents11.dta", clear 
	keep householdID N_apartch N_coresch rs_N N_ch
	duplicates drop householdID, force 

	ren householdID HHID
	merge 1:m HHID using "$working_data/children_em.dta"
	keep if _m==3 
	drop _m 
	lab var N_ch "Parents' Number of Children 2011"
	lab var N_apartch "Parents' living-apart children 2011"
	lab var N_coresch "Parents' coresident children 2011"
	lab var rs_N "Parents both alive 2011"
	lab var NRPS_N "N(Parents) in NRPS"
	 
	
	drop if residence>4 
	bys ID: gen repeatN=_N
	drop if repeatN==1
	drop repeatN
	
	drop if prov==21 
	bys ID: egen mhukou=mean(hukou)
	keep if mhukou==1 
	destring HHID, gen(hhid) 
		
	keep if N_apartch>0
		//parents with at least one living-apart child 
		
	keep if age11>24 & age11<50 
	gen age_px1=age_px if year==11 
	bys ID: egen age_px11=mean(age_px1)
	drop age_px1
	keep if age_px11>=60 
	
	** the middle-generation (adult children) have children too - three generation model 
	gen chN11=chN if year==11
 	bys ID: egen chN_11=mean(chN11) 
	keep if chN_11>0 & !mi(chN_11)

	foreach x in sibling male_sibling female_sibling elder_sibling younger_sibling{
	bys ID: egen `x'_m=mean(`x')
	drop `x' 
	ren `x'_m `x'
	}
	
	foreach x in female age edu_yr eduyr_p age_p rs_N chN dm_up ctp dm_nup nctp{
		gen mis=(mi(`x'))
		bys ID: egen Nmis=sum(mis)
		drop if Nmis==1 
		drop mis Nmis 
	}	
	
	gen countyID=substr(communityID, 1,6)
 
	preserve 
	duplicates drop HHID, force 
	bys countyID: gen HHN=_N
	keep if HHN>1
	duplicates drop countyID, force 
	bys countyID: gen countyN=_N 
 	keep countyID countyN
	save "$working_data/ChildCountySample", replace 
	restore 
	
 save "$working_data/children_em.dta", replace 
