global raw_data "$path/raw_data"
global working_data "$path/working_data" 

use "$working_data/children_em.dta", clear 

* treatment status 
	merge m:1 countyID using "$working_data/treat.dta" 
	drop if _merge!=3
	drop _merge 
	drop ct_N* 
	gen post=(year==13)
	forvalues i=1/4{
	gen trpt`i'=treat`i'*post 
	lab var trpt`i' "Treat $/times$ Post" 
	} 

	encode countyID, gen (countyid)
	order countyid, aft(countyID)
 
 	label var sibling "Number of siblings"
	gen incomegroup=1 if income_ct==1 | income_ct==2
	replace incomegr=2 if income_ct==3
	replace incomegr=3 if income_ct==4
	replace incomegr=4 if income_ct==5
	replace incomegr=5 if income_ct==6
	replace incomegr=6 if income_ct>6 & income_ct<=11
	tab incomegr,m 

 	set matsize 11000 
	bys ID: egen mchn=mean(chN)
	bys ID: egen medu_yr=max(edu_yr)
	drop if mi(medu_yr)

	drop medu_yr 
	gen edyr_fem=edu_yr*female 
	lab var edu_yr "Schooling Years"
	lab var edyr_fem "Schooling Years $\times$ Female"
	lab var cores "Coresident" 

	gen ln_incfem=ln_inc*female 
	replace income_vl=income_vl/1000 
		//in thousand CNY
	gen income_vlfem=income_vl*female 
	
	lab var income_vl "Income"
	lab var income_vlfem "Income $\times$ Female"
	lab var ln_inc "log(Income)"
	lab var ln_incfem "log(Income) $\times$ Female"

	capture lab drop edulevel 
	lab def edulevel 1"No Education" 2"Primary School Unfinished" 3"Primary School Finished" ///
		4"Secondary School (I)" 5"Secondary School (II)" 6"College and Above" 
	lab values education edulevel
	
	lab var age "Age" 
	lab var work "Currently Working" 
 	lab var ln_inc "log(Income+1)
 	lab var sibling "Number of Siblings"
	lab var rs_N "Number of Parents Alive" 
	lab var cores "Co-resident with Parents"
	replace hukou=0 if hukou==2 
	lab var hukou "Agricultural Hukou" 
	lab var chN "Number of Children"
	lab var eduyr_p "Parents' Schooling Years"
	replace rs_N=rs_N-1 
	lab var rs_N "Both Parents Alive"
	
	save "$working_data/children_em_ready.dta", replace 
