
global raw_data "$path/raw_data"
global working_data "$path/working_data"
global out_files "$path/out_files"


********************************************************************************
**  Parent samples 
********************************************************************************

use "$working_data/parents11.dta", clear 
bysort householdID: egen gen_tem=min(gender)
replace gender=3-gen_tem if rs_N==2 & mi(gender)
tab gender,m
drop gen_tem 
replace hukou=2 if hukou==3
 
drop if age<40 | age>90 
drop if mage_ch>60 | mage_ch<18 
drop gender13 lvar*  fawealth 
drop if N_ch==0 
local cont oldcare fwealth fasset_rs gender age edu_yr hukou rs_N CTP PTC GCTP PTGC CHCR minc_ch mage_ch N_ch NRPS
foreach x in `cont'{
ren `x' `x'11
}
save "$working_data/parents11_tem.dta", replace 

use "$working_data/parents13.dta", clear 
gen id_tm=substr(ID,11,2)
gen hh_tm=substr(householdID,1,9)
gen ID11=hh_tm+id_tm 
drop hh_tm id_tm 
replace hukou=2 if hukou==3
tab gender,m 
local cont oldcare fwealth fasset_rs gender age edu_yr hukou rs_N CTP PTC GCTP PTGC CHCR minc_ch mage_ch N_ch NRPS
foreach x in `cont'{
ren `x' `x'13
}
merge 1:1 ID11 using "$working_data/parents11_tem.dta" 
drop if _merge!=3
drop _merge 
order  householdID-N_ch11, alphab
order ID* *ID, bef(CHCR11)
drop ID11 
replace edu_yr11=round(edu_yr11)
replace edu_yr13=round(edu_yr13)
gen age_d=age13-age11 
sum age_d, det 
drop if age_d<0 | age_d>4 
drop age_d 
tab rs_N11 rs_N13 
gen gender_d=gender13-gender11 
gen edu_yr_d=edu_yr13-edu_yr11
sum edu_yr_d, det 
egen eduyr_m=rowmean(edu_yr13 edu_yr11)
replace edu_yr11=eduyr_m if edu_yr_d<-3 | edu_yr_d>3 
replace edu_yr13=eduyr_m if edu_yr_d<-3 | edu_yr_d>3 

replace hukou11=hukou13 if mi(hukou11) & !mi(hukou13)
replace hukou13=hukou11 if mi(hukou13) & !mi(hukou11)

gen mage_chd=mage_ch13-mage_ch11
sum mage_chd, det 
drop if mage_chd<-15 | mage_chd>8  
drop eduyr_m edu_yr_d gender_d mage_chd

save "$working_data/parents_wide.dta", replace 

reshape long `cont', i(ID) j(year)
label variable CTP "total ctp "
label variable PTC "total ptc"
label variable GCTP "total gctp "
label variable PTGC "total ptgc"
label variable CHCR "total childcare hours"
label variable minc_ch "mean year income of children"
label variable mage_ch "mean age of children"
label variable N_ch "total # of children"
lab var age "age"
lab var rs_N "=2 with spouse"
lab var edu_yr "schooling years"
lab var fwealth "total wealth of family"
lab var fasset_rs "total asset of respondent&spouse"
lab var hukou "Hukou, =1 Agri"
lab var gender "=1 male"
lab var oldcare "source of old-age support"

** Treatment Status
gen countyID=substr(communityID, 1,6)
merge m:1 countyID using "$working_data/treat.dta", keepusing (treat*)
drop if _merge!=3
drop _merge 

merge m:1 communityID using "$raw_data/psu.dta"
keep if _merge==3
drop _merge 
keep if urban==0 
drop urban 
tab areatype 
encode province, gen(prov)
drop province 
ren prov province
order province city area county, bef(ID)

save "$working_data/parents.dta", replace 

capture erase "$working_data/parents11_tem.dta" 


********************************************************************************
use "$working_data/parents.dta",clear 
********************************************************************************

 	foreach x in CTP GCTP PTC PTGC{
	replace `x'=`x'/rs_N
	}

	gen dm_up=(CTP>0)
	gen ln_up=log(CTP+1)
	gen NCTP=CTP-PTC
	gen dm_nup=(NCTP>0)
	gen ln_fw=log(fwealth+1)
	replace ln_fw=0 if fwealth<0 
	gen ln_rsw=log(fasset_rs+1)
	replace ln_rsw=0 if fasset_rs<0 
	gen ln_chinc=log(minc_ch+1)
	gen ln_nup=log(NCTP) 
	gen ctp_tem=CTP if year==11
	bysort ID: egen ctp11=mean(ctp_tem)
	drop ctp_tem 
	gen age_tem=age if year==11
	bysort ID: egen age11=mean(age_tem)
	drop age_tem 
	bysort householdID: egen hukou_m=mean(hukou)
	keep if hukou_m==1 // 1192 samples dropped 
	drop if area=="210"
	bysort householdID: egen mage11=mean(age11)
	gen post=(year==13)

	forvalues i=1/4{
	gen trpt`i'=treat`i'*post 
	lab var trpt`i' "Treat $/times$ Post"
	}
	 
	gen female=(gender==2)
	gen age2=age^2
	gen oldcare_pension=(oldcare==3)
	gen oldcare_child=(oldcare==1)
	destring countyID, replace 
	gen cores=(N_coresch>0) 
	lab var cores "Co-resident"
	lab var female "Female" 
	lab var N_ch "Number of Children"	
	lab var edu_yr "Schooling Years" 
	lab var mage_ch "Mean Age of Children" 
	lab var ln_rsw "log(Parents' Wealth)"
	lab var ln_chinc "log(Children's Income)"

	egen proyr=group(province year) 
	destring countyID, replace 
	bys ID: egen ln_rswm=max(ln_rsw)
	drop if mi(ln_rswm) 
	drop ln_rswm

	gen magech11=mage_ch if year==11 
	bys ID: egen MageCh11=mean(magech11)
	gen mxagech11=mxage_ch if year==11 
	bys ID: egen MxageCh11=mean(mxagech11)
	gen mnagech11=mnage_ch if year==11 
	bys ID: egen MnageCh11=mean(mnagech11)
	drop magech11 mnagech11 mxagech11

	drop if MxageCh11<25 | MnageCh11>50 
	drop if age11<50  

	
save "$working_data/parents_em.dta", replace 





