
global data "$path/data/CHARLS/working_data"
global tables "$path/tables/transfer"
global figure "$path/figures/transfer"
global bsc_ct2 female age edu_yr sibling chN eduyr_p age_p rs_N 
cd "$tables" 	
 
** Descriptive statistics
use "$data/children_em_ready.dta", clear 
	keep if !mi(trpt2)
	local list female age edu_yr sibling chN eduyr_p age_p rs_N dm_up ctp dm_nup  nctp
	outreg2 using sum_child, replace excel sum(detail) keep(`list') label sortvar(`list')
	capture erase sum_child.txt 

** Analysis 
use "$data/children_em_ready.dta", clear 
	egen hid=group(HHID)
	gen nctp_cap5=nctp 
	sum nctp, det 
	replace nctp=`r(p1)'   if nctp<`r(p1)' 
	replace nctp =`r(p99)'  if nctp>`r(p99)'  & !mi(nctp) 
	replace nctp_cap5 =`r(p95)'  if nctp>`r(p95)'  & !mi(nctp) 
	replace nctp_cap5 =`r(p5)'  if nctp<`r(p95)'  
	
	gen ctp_cap5=ctp 
	sum ctp, det 
	replace ctp=`r(p99)' if ctp> `r(p99)'  & !mi(ctp)  
	replace ctp_cap5=`r(p95)' if ctp_cap5>`r(p95)' &  !mi(ctp_cap5) 

** Overall Results: Including Female/Male Children 
	forvalues t=1/4{ 
	    
	** Any Upward Transfer (Up>0)
	sum dm_up if treat`t'==0 & year==11
	local mm `r(mean)'
	qui reghdfe dm_up trpt`t' , abs(countyid pro_yr)  vce(cl countyid)  
	outreg2 using transfer_`t' , replace dec(3) excel nocon keep($bsc_ct2 trpt`t')  ///
		label ctitle("Any Transfer") nonotes addsta(Control T0 Mean, `mm')
 	
	sum dm_up if treat`t'==0 & year==11 & !mi(chN)
	local mm `r(mean)'	
	qui reghdfe dm_up trpt`t'  $bsc_ct2 , abs(countyid pro_yr)  vce(cl countyid)  
	outreg2 using transfer_`t' ,  dec(3) excel nocon keep($bsc_ct2 trpt`t') ///
		label ctitle(" ") nonotes  addsta(Control T0 Mean, `mm')
 
	** Upward Transfer 
	sum ctp if treat`t'==0 & year==11
	local mm `r(mean)'
	qui reghdfe ctp trpt`t' , abs(countyid pro_yr)  vce(cl countyid)  
	outreg2 using transfer_`t' , bdec(1) sdec(1) dec(3) excel nocon keep($bsc_ct2 trpt`t')  ///
		label ctitle("Transfer") nonotes  addsta(Control T0 Mean, `mm')
 	 
	sum ctp if treat`t'==0 & year==11 & !mi(chN)
	local mm `r(mean)'			
	qui reghdfe ctp trpt`t'  $bsc_ct2 , abs(countyid pro_yr)  vce(cl countyid)  
	outreg2 using transfer_`t' , bdec(1) sdec(1)  dec(3) excel nocon keep($bsc_ct2 trpt`t') ///
		label ctitle(" ") nonotes  addsta(Control T0 Mean, `mm')
	 	
	** Net Upward Transfer
	sum nctp if treat`t'==0 & year==11
	local mm `r(mean)'	
	qui reghdfe nctp trpt`t', abs(countyid pro_yr)  vce(cl countyid)  
	outreg2 using transfer_`t' , bdec(1) sdec(1) dec(3) excel nocon keep($bsc_ct2 trpt`t')  ///
		label ctitle("NetTransfer") nonotes  addsta(Control T0 Mean, `mm')
 
	sum nctp if treat`t'==0 & year==11 & !mi(chN)
	local mm `r(mean)'	
	qui reghdfe nctp trpt`t'  $bsc_ct2 , abs(countyid pro_yr)  vce(cl countyid)  
	outreg2 using transfer_`t' , bdec(1) sdec(1) dec(3) excel nocon keep($bsc_ct2 trpt`t') ///
		label ctitle(" ") nonotes  addsta(Control T0 Mean, `mm')
 
	capture erase transfer_`t'.txt 
 }

* by Child Gender
	forvalues t=1/4{
	
	** Any Transfer 
	sum dm_up if treat`t'==0 & year==11 & !mi(chN)	& female 
	local mm `r(mean)'	
	qui reghdfe dm_up trpt`t' $bsc_ct2 if female, abs(countyid pro_yr)  vce(cl countyid)  
	outreg2 using transferByGender_`t' , replace dec(3) excel nocon keep(trpt`t')  ///
		label ctitle("Any Transfer", "Female") nonotes addsta(Control baseline mean, `mm')
 	
	sum dm_up if treat`t'==0 & year==11 & !mi(chN)	& !female 
	local mm `r(mean)'	
	 reghdfe dm_up trpt2 $bsc_ct2 if !female, abs(countyid pro_yr)  vce(cl countyid)  
	outreg2 using transferByGender_`t' ,  dec(3) excel nocon keep(trpt`t') ///
		label ctitle("Any Transfer", "Male") nonotes addsta(Control baseline mean, `mm') 
 	
	** Upward Transfer 
	sum ctp if treat`t'==0 & year==11 & !mi(chN)	& female 
	local mm `r(mean)'	
	qui reghdfe ctp trpt`t' $bsc_ct2 if female, abs(countyid pro_yr)  vce(cl countyid)  
	outreg2 using transferByGender_`t' , bdec(1) sdec(1) dec(3) excel nocon keep(trpt`t')  ///
		label ctitle("Transfer", "Female") nonotes addsta(Control baseline mean, `mm')  
 		
	sum ctp if treat`t'==0 & year==11 & !mi(chN)	& !female 
	local mm `r(mean)'	
	qui reghdfe ctp trpt`t' $bsc_ct2 if !female , abs(countyid pro_yr)  vce(cl countyid)  
	outreg2 using transferByGender_`t' , bdec(1) sdec(1)  dec(3) excel nocon keep(trpt`t') ///
		label ctitle("Transfer" ,"Male") nonotes  addsta(Control baseline mean, `mm') 
 
	** Net Upward Transfer
	sum nctp if treat`t'==0 & year==11 & !mi(chN)	& female 
	local mm `r(mean)'	
	qui reghdfe nctp trpt2 $bsc_ct2 if female , abs(countyid pro_yr)  vce(cl countyid)  
	outreg2 using transferByGender_`t' ,bdec(1) sdec(1)  dec(3) excel nocon keep(trpt`t')  ///
		label ctitle("Net Transfer" ,"Female") nonotes  addsta(Control baseline mean, `mm') 
 		
	sum nctp if treat`t'==0 & year==11 & !mi(chN)	& !female 
	local mm `r(mean)'	
	qui reghdfe nctp trpt`t' $bsc_ct2 if ! female, abs(countyid pro_yr)  vce(cl countyid)  
	outreg2 using transferByGender_`t' ,  bdec(1) sdec(1) dec(3) excel nocon keep(trpt`t') ///
		label ctitle("Net Transfer" ,"Male") nonotes  addsta(Control baseline mean, `mm') 
	
	capture erase transferByGender_`t'.txt 
 }
 

** Test Gender Difference 	

	local t 4
	local ctr trpt`t'
	eststo EF3: qui reg dm_up trpt`t' $bsc_ct2 i.countyid i.pro_yr if female 
	eststo EM3: qui reg dm_up trpt`t' $bsc_ct2 i.countyid i.pro_yr if ! female 
	eststo EF4: qui reg ctp trpt`t' $bsc_ct2 i.countyid i.pro_yr if female
	eststo EM4: qui reg ctp trpt`t' $bsc_ct2 i.countyid i.pro_yr if ! female 
	eststo EF5: qui reg nctp trpt`t' $bsc_ct2 i.countyid i.pro_yr if female
	eststo EM5: qui reg nctp trpt`t' $bsc_ct2 i.countyid i.pro_yr if ! female
		
	forvalues i=3/5{
	suest EF`i' EM`i' , vce(cl countyid)
	test [EF`i'_mean]`ctr' = [EM`i'_mean]`ctr' 
	local chisq`i' `r(chi2)' 
	local pvl`i' `r(p)'
	}
	
	dis `chisq3' 	
	dis `pvl3' 		
	dis `chisq4' 	
	dis `pvl4'		
	dis `chisq5' 	
	dis `pvl5'		
	 

** Excluding Adult Children Living with Parents 

	replace cores=1 if residence<=2 //same household or apartment 
 	bys ID: egen mcores=mean(cores)
	gen cores3=cores if year==13
	bys ID: egen cores13=mean(cores3)
	drop cores3 
	bys ID: gen rpt=_n 
	drop if mcores==1  
	
	foreach t in 2 4 {
	
	qui reghdfe dm_up trpt`t' $bsc_ct2 if female, abs(countyid pro_yr)  vce(cl countyid)  
	outreg2 using transfer_NoCores`t' , replace dec(3) excel nocon keep(trpt`t')  ///
		label ctitle("Any Transfer", "Female") nonotes 
 	
	qui reghdfe dm_up trpt`t' $bsc_ct2 if !female, abs(countyid pro_yr)  vce(cl countyid)  
	outreg2 using transfer_NoCores`t' ,  dec(3) excel nocon keep(trpt`t') ///
		label ctitle("Any Transfer", "Male") nonotes 
 	
	qui reghdfe ctp trpt`t' $bsc_ct2 if female, abs(countyid pro_yr)  vce(cl countyid)  
	outreg2 using transfer_NoCores`t' , bdec(1) sdec(1) dec(3) excel nocon keep(trpt`t')  ///
		label ctitle("Transfer", "Female") nonotes 
 		
	qui reghdfe ctp trpt`t' $bsc_ct2 if !female , abs(countyid pro_yr)  vce(cl countyid)  
	outreg2 using transfer_NoCores`t' , bdec(1) sdec(1)  dec(3) excel nocon keep(trpt`t') ///
		label ctitle("Transfer" ,"Male") nonotes 
 
	qui reghdfe nctp trpt`t' $bsc_ct2 if female , abs(countyid pro_yr)  vce(cl countyid)  
	outreg2 using transfer_NoCores`t' ,bdec(1) sdec(1)  dec(3) excel nocon keep(trpt`t')  ///
		label ctitle("Net Transfer" ,"Female") nonotes 
 		
	qui reghdfe nctp trpt`t' $bsc_ct2 if ! female, abs(countyid pro_yr)  vce(cl countyid)  
	outreg2 using transfer_NoCores`t' ,  bdec(1) sdec(1) dec(3) excel nocon keep(trpt`t') ///
		label ctitle("Net Transfer" ,"Male") nonotes 
	
	capture erase transfer_NoCores`t'.txt 
	}
	