
global data "$path/data/CHARLS/working_data"
global tables "$path/tables/transfer"
global figure "$path/figures/transfer"
cd "$tables" 

** Summary Statistics ** 

use "$data/parents_em.dta", clear 

set matsize 11000
replace rs_N=rs_N-1 
lab var rs_N "Spouse is Alive"
keep if age11>=60
keep if !mi(trpt2)
	
	local list age female edu_yr rs_N mage_ch  N_ch N_mch dm_up CTP dm_nup NCTP  
	outreg2 using sum_parent, replace excel sum(detail) keep(`list') label sortvar(`list')
	capture erase sum_parent.txt 
	

** Analysis ** 

use "$data/parents_em.dta", clear 

	sum CTP, det 
	local ctpp99 `r(p99)' 
	local ctpp1 `r(p1)' 
	
	sum PTC, det
	local ptcp99 `r(p99)' 
	local ptcpp1 `r(p1)' 
	
	sum NCTP, det 
	local nctpp99 `r(p99)' 
	local nctpp1 `r(p1)' 

	replace CTP=`ctpp99' if CTP>`ctpp99' & !mi(CTP) 
	replace PTC=`ptcp99' if PTC>`ptcp99' & !mi(PTC) 
	replace NCTP=`nctpp99' if NCTP>`nctpp99'  & !mi(NCTP)  
	replace NCTP=`nctpp1' if NCTP<`nctpp1'  & !mi(NCTP) 
	
			
local control age female edu_yr rs_N mage_ch  N_ch N_mch 

forvalues i =1/4 {  
	local ctr trpt`i' 
	
	preserve 
	keep if age11<58 & age11>=50 
		qui reghdfe  dm_up	trpt`i'  `control', abs(proyr i.countyID) vce(cl countyID) 
		sum dm_up if treat`i'==0 & year==11 
		local mean1 `r(mean)'
		sum dm_up if treat`i'==0 & year==13 
		local mean3 `r(mean)'
		local dmean `mean3'-`mean1' 
		outreg2 using PrTrstY_treat`i', dec(3) excel keep(`ctr') addsta("Control Baseline Mean", `mean1', "Control T1-T0 Mean", `dmean')  label ctitle(Any Transfer) nonotes nocons replace 

		qui reghdfe  dm_nup trpt`i'  `control', abs(proyr i.countyID) vce(cl countyID)
		sum dm_nup if treat`i'==0 & year==11 
		local mean1 `r(mean)'
		sum dm_nup if treat`i'==0 & year==13 
		local mean3 `r(mean)'
		local dmean `mean3'-`mean1' 
		outreg2 using PrTrstY_treat`i', dec(3) excel keep(`ctr') addsta("Control Baseline Mean", `mean1', "Control T1-T0 Mean", `dmean') label ctitle(Any Net Transfer)  nocons
		
		qui reghdfe  CTP trpt`i'  `control', abs(proyr i.countyID) vce(cl countyID)
		sum CTP if treat`i'==0 & year==11 
		local mean1 `r(mean)'
		sum CTP if treat`i'==0 & year==13 
		local mean3 `r(mean)'
		local dmean `mean3'-`mean1' 
		outreg2 using PrTrstY_treat`i', dec(3) bdec(1) sdec(1) excel keep(`ctr') addsta("Control Baseline Mean", `mean1', "Control T1-T0 Mean", `dmean')  label ctitle(Transfer) nocons
		
		qui reghdfe  NCTP trpt`i'  `control', abs(proyr i.countyID) vce(cl countyID)
		sum NCTP if treat`i'==0 & year==11 
		local mean1 `r(mean)'
		sum NCTP if treat`i'==0 & year==13 
		local mean3 `r(mean)'
		local dmean `mean3'-`mean1' 
		outreg2 using PrTrstY_treat`i', dec(3) bdec(1) sdec(1) excel keep(`ctr') addsta("Control Baseline Mean", `mean1', "Control T1-T0 Mean", `dmean')  label ctitle(Net Transfer) nocons
		
	capture erase PrTrstY_treat`i'.txt 	
	restore 

	preserve 
	keep if age11>=60 
		qui reghdfe  dm_up	trpt`i'  `control', abs(proyr i.countyID) vce(cl countyID) 
		sum dm_up if treat`i'==0 & year==11 
		local mean1 `r(mean)'
		sum dm_up if treat`i'==0 & year==13 
		local mean3 `r(mean)'
		local dmean `mean3'-`mean1' 
		outreg2 using PrTrstO_treat`i', dec(3) excel keep(`ctr') addsta("Control Baseline Mean", `mean1', "Control T1-T0 Mean", `dmean')  label ctitle(Any Transfer) nonotes  nocons replace 

		qui reghdfe  dm_nup trpt`i'  `control', abs(proyr i.countyID) vce(cl countyID)
		sum dm_nup if treat`i'==0 & year==11 
		local mean1 `r(mean)'
		sum dm_nup if treat`i'==0 & year==13 
		local mean3 `r(mean)'
		local dmean `mean3'-`mean1' 
		outreg2 using PrTrstO_treat`i', dec(3) excel keep(`ctr') addsta("Control Baseline Mean", `mean1', "Control T1-T0 Mean", `dmean')  label ctitle(Any Net Transfer) nocons

		qui reghdfe  CTP trpt`i'  `control', abs(proyr i.countyID) vce(cl countyID)
		sum CTP if treat`i'==0 & year==11 
		local mean1 `r(mean)'
		sum CTP if treat`i'==0 & year==13 
		local mean3 `r(mean)'
		local dmean `mean3'-`mean1' 
		outreg2 using PrTrstO_treat`i', dec(3) bdec(1) sdec(1) excel keep(`ctr') addsta("Control Baseline Mean", `mean1', "Control T1-T0 Mean", `dmean')  label ctitle(Transfer)  nocons
		
		qui reghdfe  NCTP trpt`i'  `control', abs(proyr i.countyID) vce(cl countyID)
		sum NCTP if treat`i'==0 & year==11 
		local mean1 `r(mean)'
		sum NCTP if treat`i'==0 & year==13 
		local mean3 `r(mean)'
		local dmean `mean3'-`mean1' 
		outreg2 using PrTrstO_treat`i', dec(3) bdec(1) sdec(1) excel keep(`ctr') addsta("Control Baseline Mean", `mean1', "Control T1-T0 Mean", `dmean')  label ctitle(Net Transfer)  nocons
			
	capture erase PrTrstO_treat`i'.txt 	
	restore 
}

