
global working_data "$path/working_data"
global table "$path/tables"
global figure "$path/figures"
grstyle init
grstyle set plain,  hor 	

** Prepare RD Dataset 

use "$working_data/parents_em.dta", clear 
keep countyID treat* 
duplicates drop countyID , force 
save temp.dta, replace 

use "$working_data/parents11.dta", clear 
	merge 1:1 ID using "$working_data/pension11.dta", keepusing(nrsp mt_pay urban countyID)
	keep if _merge==3 
	drop _merge 
	gen nrsp_rc=(mt_pay>0 & mt_pay!=.)
	replace nrsp_rc=0 if nrsp==0 & nrsp_rc==. 
	gen year=11 
	save temp11.dta, replace 
	
 use "$working_data/parents13.dta", clear 
	merge 1:1 ID using "$working_data/pension13.dta", keepusing(nrsp mt_pay urban countyID)
	keep if _merge==3 
	drop _merge 
	gen nrsp_rc=(mt_pay>0 & mt_pay!=.)
	replace nrsp_rc=0 if nrsp==0 & nrsp_rc==. 
	gen year=13 

	append using temp11.dta
 
	gen ntr=CTP-PTC 
	foreach x in CTP PTC ntr {
	replace `x'=`x'/rs_N
	}

	sum CTP, det 
	local p99 `r(p99)' 
	sum ntr, det 
	local np99 `r(p99)' 
	local np1 `r(p1)' 

	replace CTP=`p99' if CTP>`p99' & !mi(CTP) 
	replace ntr=`np99' if ntr>`np99' & !mi(ntr) 
	replace ntr=`np1'  if ntr<`np1'  & !mi(ntr) 

	gen dmctp=(CTP>0)
	gen dmnctp=(ntr>0)
	replace dmctp=. if mi(CTP)
	replace dmnctp=. if mi(ntr) 
	replace rs_N=rs_N-1
	ren CTP ctp 
	destring countyID, replace 
	destring communityID, replace 

	keep if hukou==1 
	keep if N_ch>0
	drop if mxage_ch<25 | mnage_ch>50 
	gen N_ncrch=N_ch-N_coresch 
	keep if age>=40 & age<=80	
	
	merge m:1 countyID using temp.dta 
	keep if _m==3
	drop _m 
	
	* partial out county and year fixed effects 
	foreach x in dmctp dmnctp ctp ntr gender edu_yr mage_ch N_ch rs_N  N_mch {
		qui reg `x' i.countyID //i.year 
		predict `x'_res if e(sample), residuals
		} 	
		
	keep dmctp dmnctp ctp ntr gender edu_yr mage_ch N_ch rs_N  N_mch communityID countyID nrsp_rc age	dmctp_res dmnctp_res ctp_res ntr_res gender_res edu_yr_res mage_ch_res N_ch_res rs_N_res N_mch_res year age  N_ncrch treat2 
	save "$working_data/rddata.dta", replace 
 	

** Density Test 

	use "$working_data/rddata.dta", clear 
	keep if year==13  

 	rddensity age, c(60)  plot hist_range(50 70) hist_n(20 20) histl_opt(color(maroon*.35) lcolor(white) barw(.5)) histr_opt(color(navy*.35) barw(.5) lcolor(white)) plot_range(50 70) p(1) q(2) graph_opt(legend(off) xlab(50(5)70) xtitle("Age", size(medsmall) margin(b=1)) note("Note: kernel=triangular; VCE method=jackknife; order est. (p)=1; order bias (q)=2; T=-0.486; {it:p}-val=0.627", span size(small)) legend( size(small) pos(1) col(1) ring(0)) xlab(, labsize(small)) ylab(, labsize(small)))  
	graph export "$figure/Density_test.pdf", replace  


** First Stage and Reduced-Form 
use "$working_data/rddata.dta", clear 
	keep if year==13 
	
** First Stage 
	rdplot nrsp_rc age if age>=49 & age<=71,  c(60) p(1) nbins(9 9)  h(11 11) graph_options( title("") legend(off) xlabel(50(5)70, labsize(med)) ylab(, labsize(med)) xscale(range(50 70)) ytitle("Receiving Pensions", size(medlarge) margin(r=3)) xtitle(Age, size(medlarge) margin(t=3))  graphregion(color(white)))  
	graph display, xsize(16) ysize(10)
	graph export "$figure/FirstStage.pdf", replace 

** Reduced Form 
	lab var dmctp_res "Any Transfer"
	lab var dmnctp_res "Any Net Transfer"
	lab var ntr_res  "Net Transfer (k)"
	lab var ctp_res  "Transfer (k)"
	replace ntr =ntr /1000
	replace ctp =ctp /1000
	replace age=round(age)
	foreach x in dmctp dmnctp ctp ntr  {
	local label : variable label `x'_res
	rdplot `x' age if age>54 & age<66, c(60)  p(1) nbins(5 5) h(5 5)  ///
		graph_options( title("") legend(off) ylabel(#4, labsize(medsmall)) ///
		ytitle("`label'", size(medium)) xtitle(Age, size(medium)) xlabel(#3, labsize(medsmall))) ci(90) 
	graph save "$figure/`x'.gph" , replace 
	}

	cd "$figure"
	graph combine dmctp.gph dmnctp.gph ctp.gph ntr.gph
	graph display, xsize(16) ysize(11)
	graph export "$figure/ReducedForm.pdf", replace  
 
** Treatment Effect Estimation (MSE BW)
use "$working_data/rddata.dta", clear 
	keep if year==13  
	local ctr gender edu_yr  N_ch rs_N  mage_ch N_mch

	capture log close 
	log using "$table/rdrobust_treatment", s replace
	log on 
	*** MSE BW & Kernel dmnctp ctp ntr 
	foreach x in dmctp dmnctp ctp ntr {
		rdrobust `x'_res age, c(60) p(1) q(2) fuzzy(nrsp_rc) covs(`ctr') vce(cluster countyID) 
	 
	*** MSE BW & Epanechnikov 
		rdrobust `x'_res age, c(60) p(1) q(2) fuzzy(nrsp_rc) covs(`ctr') vce(cluster countyID) kernel(epa) 
	 
	*** MSE BW & Uniform 
		rdrobust `x'_res age, c(60) p(1) q(2) fuzzy(nrsp_rc) covs(`ctr') vce(cluster countyID) kernel(uni) 
		}	
	log off 	

** Treatment Effect Estimation (Manually Set BW)
	 
use "$working_data/rddata.dta", clear 
	keep if year==13  
	local ctr gender edu_yr mage_ch N_ch rs_N  N_mch 

	capture log close 
	foreach h in 4 6 8 10{

	***   Triangular 

	log using "$table/rdrobust_treatment_h`h'_triangular", s replace
	log on 

	foreach x in dmctp dmnctp ctp ntr {
		rdrobust `x'_res age, c(60) p(1) q(2) fuzzy(nrsp_rc) covs(`ctr') vce(cluster countyID) h(`h' )
	}

	log off 	
	log close 


	***  Uniform 
	log using "$table/rdrobust_treatment_h`h'_uniform", s replace
	log on 

	foreach x in dmctp dmnctp ctp ntr {
		rdrobust `x'_res age, c(60) p(1) q(2) fuzzy(nrsp_rc) covs(`ctr') vce(cluster countyID) h(`h' ) kernel(uni)
	}
	log off 	
	log close 
	 
	*** Epanechnikov 
	log using "$table/rdrobust_treatment_h`h'_epane", s replace
	log on 

	foreach x in dmctp dmnctp ctp ntr {
		rdrobust `x'_res age, c(60) p(1) q(2) fuzzy(nrsp_rc) covs(`ctr') vce(cluster countyID) h(`h' ) kernel(epa)
		}
	log off 	
	log close 
	}


** Covariates  

use "$working_data/rddata.dta", clear 
	keep if year==13 
	capture log close 

	log using "$table/rdrobust_covariates", s replace
	log on 

	foreach x in gender edu_yr rs_N mage_ch N_ch  N_mch  { 
		rdrobust `x'_res age, c(60) p(1) q(2)  vce(cluster countyID) h(6)
		 
		rdrobust `x'_res age, c(60) p(1) q(2) vce(cluster countyID) kernel(epa) h(6)
	 
		rdrobust `x'_res age, c(60) p(1) q(2) vce(cluster countyID)	kernel(uni) h(6)
		}	
	log off 	


** Placebo Test: Wave 1 Counties without NRPS 
	use "$working_data/rddata.dta", clear 
	keep if year==11 & treat2==1 
	 
	capture log close 
	log using "$table/rdrobust_placebo", s replace
	log on 
	 
		foreach x in dmctp dmnctp ctp ntr {
		rdrobust `x'_res age, c(60) p(1) q(2)  covs(`ctr') vce(cluster countyID) h(6)
		 
		rdrobust `x'_res age, c(60) p(1) q(2) covs(`ctr') vce(cluster countyID)  kernel(epa) h(6)
	 
		rdrobust `x'_res age, c(60) p(1) q(2) covs(`ctr') vce(cluster countyID) kernel(uni) h(6)
		}	
	log off 	

